import React, { PureComponent } from 'react';
import { Link, withRouter, Redirect } from "react-router-dom";
import { connect } from 'react-redux';
import { bindActionCreators } from 'redux';
import axios from 'axios';

import storageKey from './../../utils/storageKey';
import { signInStateZeroing } from './../../actions/auth/signIn';
import { LOG_OUT_URL } from './../../constants/auth';

import * as routes from '../../constants/routes';

//pure component + make storage check an action -> connect router
class Header extends PureComponent {
    handleLogOut = () => {
        console.log(this.props)
        const { history, zeroState } = this.props;

        axios.get(LOG_OUT_URL, {})
            .then(() => {
                console.log('request was succesfull')
                localStorage.removeItem(storageKey);
                zeroState();
                history.push('/sign-in');
            })
            .catch(e => alert('Sorry, something bad happened, try log out later \n' + e.message));
    }

    render() {
        const { role } = this.props;

        return (

            <nav class="navbar navbar-expand-lg navbar-expand-lg bg-gradient1 p-4 position-absolute w-100 ">
                <Link to={routes.LANDING} class="navbar-brand font-label text-af" href="#">Test.io</Link>
                <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="Toggle navigation">
                    <span class="navbar-toggler-icon" />
                </button>

                <div class="collapse navbar-collapse" id="navbarSupportedContent">
                    <ul class="navbar-nav mr-auto">
                        <li class="nav-item active">
                            <Link onClick={this.handleClick} class="nav-link text-shadow font-ci font-ci-bold" to={routes.HOME}>Home <span class="sr-only">(current)</span></Link>
                        </li>
                        <li class="nav-item">
                            <Link onClick={this.handleClick} class="nav-link text-shadow font-ci font-ci-bold" to={routes.PROFILE}>Profile</Link>
                        </li>
                        <li class="nav-item">
                            <Link onClick={this.handleClick} class="nav-link text-shadow font-ci font-ci-bold " to={routes.TESTS}>Tests</Link>
                        </li>
                        <li class="nav-item">
                            <Link onClick={this.handleClick} class="nav-link text-shadow font-ci font-ci-bold " to={routes.CATEGORIES}>Catigories</Link>

                        </li>
                        {role
                                ?
                        <li class="nav-item dropdown">

                            <a class="nav-link text-shadow font-ci font-ci-bold" href="#" id="navbarDropdown" role="button" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                                Menu Admin
                                </a>
                            <div class="dropdown-menu" aria-labelledby="navbarDropdown">
                            <Link to={routes.DELETE_USER} className="nav-link text-secondary text-shadow font-ci">Delete User</Link>
                                <Link to={routes.CREATE_TEST} className="nav-link text-secondary text-shadow font-ci">Create Test</Link>
                                <Link to={routes.CHANGE_TEST} className="nav-link text-secondary text-shadow font-ci">Change Test</Link>
                                
                                <Link to={routes.CREATE_CATEGORY} className="nav-link text-secondary text-shadow font-ci">Create Category</Link>

                                
                            </div>
                        </li>
                                
                                :
                                null
                        }
                    </ul>
                    
                    <div className="controls">
                        {
                            role !== null
                                ?
                                <button onClick={this.handleLogOut} className="btn  btn-outline-light ml-2 bg-stone">Log Out</button>
                                :
                                <React.Fragment>
                                    <Link to={routes.SIGN_IN}>
                                        <button className="btn  btn-outline-light ml-2 bg-stone">Sign In</button>
                                    </Link>
                                    <Link to={routes.SIGN_UP}>
                                        <button className="btn  btn-outline-light ml-2 bg-stone">Sign Up</button>
                                    </Link>
                                </React.Fragment>
                        }
{/* =======

                    <div className="">
                        <Link to={routes.SIGN_IN}>
                            <button className="btn  btn-outline-light bg-stone">Sign In</button>
                        </Link>
                        <Link to={routes.SIGN_UP}>
                            <button className="btn  btn-outline-light ml-2 bg-stone">Sign Up</button>

                        </Link>
                        <button onClick={this.handleLogOut} className="btn btn-outline-primary">Log Out</button>
>>>>>>> new_Sveta */}
                    </div>
                </div>
            
            </nav>
        )
    }
}

const mapStateToProps = state => ({
    role: state.tokenCheckout.role,
});
const mapDispatchToProps = dispatch => bindActionCreators({
    zeroState: signInStateZeroing
}, dispatch)

export default withRouter(connect(mapStateToProps, mapDispatchToProps)(Header));